@@ -1,6 +1,14 @@
-from wikibaseintegrator import wbi_core, wbi_fastrun, wbi_datatype
+from collections import defaultdict
+from typing import Any
 
-wbi_fastrun.FastRunContainer.debug = True
+from wikibaseintegrator import WikibaseIntegrator, wbi_fastrun
+from wikibaseintegrator.datatypes import BaseDataType, ExternalID, Item
+from wikibaseintegrator.wbi_config import config as wbi_config
+from wikibaseintegrator.wbi_enums import ActionIfExists
+
+wbi_config['USER_AGENT'] = 'WikibaseIntegrator-pytest/1.0 (test_wbi_fastrun.py)'
+
+wbi = WikibaseIntegrator()
 
 
 def test_query_data():
@@ -11,7 +19,7 @@ def test_query_data():
     This tests that the fast run container correctly queries data from wikidata and stores it in the appropriate format
     without getting references
     """
-    frc = wbi_fastrun.FastRunContainer(base_filter={'P699': ''}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine)
+    frc = wbi_fastrun.FastRunContainer(base_filter=[BaseDataType(prop_nr='P699')], base_data_type=BaseDataType)
     # get a string value
     frc._query_data('P699')
     # wikidata-item value
@@ -27,14 +35,14 @@ def test_query_data():
     d = frc.prop_data['Q10874']['P699'][statement_id]
     # d looks like: {'qual': set(), 'ref': {}, 'v': 'DOID:1432'}
     assert all(x in d for x in {'qual', 'ref', 'v'})
-    assert frc.prop_data['Q10874']['P699'][statement_id]['v'].startswith('DOID:')
+    assert frc.prop_data['Q10874']['P699'][statement_id]['v'].startswith('"DOID:')
 
     # item
     assert list(frc.prop_data['Q10874']['P828'].values())[0]['v'] == "Q18228398"
 
     # uri
     v = {x['v'] for x in frc.prop_data['Q10874']['P2888'].values()}
-    assert all(y.startswith("http") for y in v)
+    assert all(y.startswith("<http") for y in v)
 
 
 # # Fail too often
@@ -43,14 +51,14 @@ def test_query_data():
 #     test_fastrun.test_query_data_unit
 #     This hits live wikidata and may change !!
 #     """
-#     frc = wbi_fastrun.FastRunContainer(base_filter={'P2044': '', 'P30': 'Q46'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine, debug=True)
+#     frc = wbi_fastrun.FastRunContainer(base_filter={'P2044': '', 'P30': 'Q46', 'P31': 'Q5119'}, base_data_type=BaseDataType)
 #     # get a quantity value
 #     frc._query_data('P2044', use_units=True)
 #
-#     assert 'Q583' in frc.prop_data
-#     assert 'P2044' in frc.prop_data['Q583']
-#     statement_id = list(frc.prop_data['Q583']['P2044'].keys())[0]
-#     assert frc.prop_data['Q583']['P2044'][statement_id]['unit'] == 'Q11573'
+#     assert 'Q90' in frc.prop_data
+#     assert 'P2044' in frc.prop_data['Q90']
+#     statement_id = list(frc.prop_data['Q90']['P2044'].keys())[0]
+#     assert frc.prop_data['Q90']['P2044'][statement_id]['unit'] == 'Q11573'
 
 
 def test_query_data_ref():
@@ -61,7 +69,7 @@ def test_query_data_ref():
     This tests that the fast run container correctly queries data from wikidata and stores it in the appropriate format
     WITH getting references
     """
-    frc = wbi_fastrun.FastRunContainer(base_filter={'P699': ''}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine, use_refs=True)
+    frc = wbi_fastrun.FastRunContainer(base_filter=[BaseDataType(prop_nr='P699')], base_data_type=BaseDataType, use_refs=True)
     frc._query_data('P699')
 
     # https://www.wikidata.org/wiki/Q10874
@@ -79,7 +87,7 @@ def test_query_data_ref():
       'v': 'DOID:1432'}
     """
     assert all(x in d for x in {'qual', 'ref', 'v'})
-    assert frc.prop_data['Q10874']['P699'][statement_id]['v'].startswith('DOID:')
+    assert frc.prop_data['Q10874']['P699'][statement_id]['v'].startswith('"DOID:')
     assert len(d['ref']) > 0
     ref_id = list(d['ref'].keys())[0]
     ref = d['ref'][ref_id]
@@ -87,74 +95,76 @@ def test_query_data_ref():
 
 
 class FastRunContainerFakeQueryDataEnsembl(wbi_fastrun.FastRunContainer):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
         self.prop_dt_map = {'P248': 'wikibase-item', 'P594': 'external-id'}
         self.prop_data['Q14911732'] = {'P594': {
             'fake statement id': {
                 'qual': set(),
                 'ref': {'fake ref id': {
-                    ('P248', 'Q29458763'),  # stated in ensembl Release 88
-                    ('P594', 'ENSG00000123374')}},
-                'v': 'ENSG00000123374'}}}
-        self.rev_lookup = {'ENSG00000123374': {'Q14911732'}}
+                    ('P248',
+                     'Q106833387'),
+                    ('P594',
+                     'ENSG00000123374')}},
+                'unit': '1',
+                'v': '"ENSG00000123374"'}}}
+        self.rev_lookup = defaultdict(set)
+        self.rev_lookup['"ENSG00000123374"'].add('Q14911732')
 
 
 class FastRunContainerFakeQueryDataEnsemblNoRef(wbi_fastrun.FastRunContainer):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
         self.prop_dt_map = {'P248': 'wikibase-item', 'P594': 'external-id'}
         self.prop_data['Q14911732'] = {'P594': {
             'fake statement id': {
                 'qual': set(),
-                'ref': dict(),
+                'ref': {},
                 'v': 'ENSG00000123374'}}}
-        self.rev_lookup = {'ENSG00000123374': {'Q14911732'}}
+        self.rev_lookup = defaultdict(set)
+        self.rev_lookup['"ENSG00000123374"'].add('Q14911732')
 
 
 def test_fastrun_ref_ensembl():
     # fastrun checks refs
-    frc = FastRunContainerFakeQueryDataEnsembl(base_filter={'P594': '', 'P703': 'Q15978631'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine, use_refs=True)
+    frc = FastRunContainerFakeQueryDataEnsembl(base_filter=[BaseDataType(prop_nr='P594'), Item(prop_nr='P703', value='Q15978631')], base_data_type=BaseDataType, use_refs=True)
 
     # statement has no ref
-    frc.debug = True
-    statements = [wbi_datatype.ExternalID(value='ENSG00000123374', prop_nr='P594')]
+    statements = [ExternalID(value='ENSG00000123374', prop_nr='P594')]
     assert frc.write_required(data=statements)
 
     # statement has the same ref
-    statements = [wbi_datatype.ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[wbi_datatype.ItemID("Q29458763", "P248", is_reference=True),
-                                                                                                wbi_datatype.ExternalID("ENSG00000123374", "P594", is_reference=True)]])]
+    statements = [ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[Item("Q106833387", prop_nr="P248"), ExternalID("ENSG00000123374", prop_nr="P594")]])]
     assert not frc.write_required(data=statements)
 
     # new statement has an different stated in
-    statements = [wbi_datatype.ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[wbi_datatype.ItemID("Q99999999999", "P248", is_reference=True),
-                                                                                                wbi_datatype.ExternalID("ENSG00000123374", "P594", is_reference=True)]])]
+    statements = [ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[Item("Q99999999999", prop_nr="P248"), ExternalID("ENSG00000123374", prop_nr="P594", )]])]
     assert frc.write_required(data=statements)
 
     # fastrun don't check references, statement has no reference,
-    frc = FastRunContainerFakeQueryDataEnsemblNoRef(base_filter={'P594': '', 'P703': 'Q15978631'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine,
+    frc = FastRunContainerFakeQueryDataEnsemblNoRef(base_filter=[BaseDataType(prop_nr='P594'), Item(prop_nr='P703', value='Q15978631')], base_data_type=BaseDataType,
                                                     use_refs=False)
-    statements = [wbi_datatype.ExternalID(value='ENSG00000123374', prop_nr='P594')]
+    statements = [ExternalID(value='ENSG00000123374', prop_nr='P594')]
     assert not frc.write_required(data=statements)
 
     # fastrun don't check references, statement has reference,
-    frc = FastRunContainerFakeQueryDataEnsemblNoRef(base_filter={'P594': '', 'P703': 'Q15978631'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine,
+    frc = FastRunContainerFakeQueryDataEnsemblNoRef(base_filter=[BaseDataType(prop_nr='P594'), Item(prop_nr='P703', value='Q15978631')], base_data_type=BaseDataType,
                                                     use_refs=False)
-    statements = [wbi_datatype.ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[wbi_datatype.ItemID("Q123", "P31", is_reference=True)]])]
+    statements = [ExternalID(value='ENSG00000123374', prop_nr='P594', references=[[Item("Q123", prop_nr="P31")]])]
     assert not frc.write_required(data=statements)
 
 
 class FakeQueryDataAppendProps(wbi_fastrun.FastRunContainer):
     # an item with three values for the same property
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         super().__init__(*args, **kwargs)
-        self.debug = True
         self.prop_dt_map = {'P527': 'wikibase-item', 'P248': 'wikibase-item', 'P594': 'external-id'}
-        self.rev_lookup = {
-            'Q24784025': {'Q3402672'},
-            'Q24743729': {'Q3402672'},
-            'Q24782625': {'Q3402672'},
-        }
+
+        self.rev_lookup = defaultdict(set)
+        self.rev_lookup['Q24784025'].add('Q3402672')
+        self.rev_lookup['Q24743729'].add('Q3402672')
+        self.rev_lookup['Q24782625'].add('Q3402672')
+
         self.prop_data['Q3402672'] = {'P527': {
             'Q3402672-11BA231B-857B-498B-AC4F-91D71EE007FD': {'qual': set(),
                                                               'ref': {
@@ -180,22 +190,22 @@ def test_append_props():
     # https://www.wikidata.org/wiki/Q3402672#P527
 
     # don't consider refs
-    frc = FakeQueryDataAppendProps(base_filter={'P352': '', 'P703': 'Q15978631'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine)
+    frc = FakeQueryDataAppendProps(base_filter=[BaseDataType(prop_nr='P352'), Item(prop_nr='P703', value='Q15978631')], base_data_type=BaseDataType)
     # with append
-    statements = [wbi_datatype.ItemID(value='Q24784025', prop_nr='P527', if_exists='APPEND')]
-    assert frc.write_required(data=statements, cqid=qid) is False
+    statements = [Item(value='Q24784025', prop_nr='P527')]
+    assert frc.write_required(data=statements, action_if_exists=ActionIfExists.APPEND_OR_REPLACE, cqid=qid) is False
     # with force append
-    statements = [wbi_datatype.ItemID(value='Q24784025', prop_nr='P527', if_exists='FORCE_APPEND')]
-    assert frc.write_required(data=statements, cqid=qid) is True
+    statements = [Item(value='Q24784025', prop_nr='P527')]
+    assert frc.write_required(data=statements, action_if_exists=ActionIfExists.FORCE_APPEND, cqid=qid) is True
     # without append
-    statements = [wbi_datatype.ItemID(value='Q24784025', prop_nr='P527')]
+    statements = [Item(value='Q24784025', prop_nr='P527')]
     assert frc.write_required(data=statements, cqid=qid) is True
 
     # if we are in append mode, and the refs are different, we should write
-    frc = FakeQueryDataAppendProps(base_filter={'P352': '', 'P703': 'Q15978631'}, base_data_type=wbi_datatype.BaseDataType, engine=wbi_core.ItemEngine, use_refs=True)
+    frc = FakeQueryDataAppendProps(base_filter=[BaseDataType(prop_nr='P352'), Item(prop_nr='P703', value='Q15978631')], base_data_type=BaseDataType, use_refs=True)
     # with append
-    statements = [wbi_datatype.ItemID(value='Q24784025', prop_nr='P527', if_exists='APPEND')]
-    assert frc.write_required(data=statements, cqid=qid) is True
+    statements = [Item(value='Q24784025', prop_nr='P527')]
+    assert frc.write_required(data=statements, cqid=qid, action_if_exists=ActionIfExists.APPEND_OR_REPLACE) is True
     # without append
-    statements = [wbi_datatype.ItemID(value='Q24784025', prop_nr='P527')]
+    statements = [Item(value='Q24784025', prop_nr='P527')]
     assert frc.write_required(data=statements, cqid=qid) is True
